require 'logger'
require_relative 'test_helper'
require_relative '../lib/dot_env'

describe DotEnv do
  before { ENV['APP_ENV'] = nil }

  describe "set_environment" do
    describe "the happy path" do
      let(:env) { DotEnv::Environment.new(DotEnv::Parser, ARGV) }

      before do
        DotEnv.set_environment('spec/fixtures/dotenv/testenv')
      end

      it "reads the given environment settings file and sets the environment" do
        ENV['APP_NAME'].must_equal 'testapp'
        ENV['AN_ARRAY'].must_equal '[egy, ketto, harom]'
        ENV['UNBELIEVABLE'].must_equal 'True'
        ENV['SOMEWHERE'].must_equal ENV['HOME']
      end

      it "can read back those settings" do
        env.fetch('APP_NAME').must_equal 'testapp'
        env.fetch('AN_ARRAY').must_equal ['egy', 'ketto', 'harom']
        env.fetch('UNBELIEVABLE').must_equal true
        env.fetch('SOMEWHERE').must_equal ENV['HOME']
      end
    end

    describe "when there is no environment setting file found" do
      it "must return 'development' environment" do
        DotEnv.set_environment('path/to/nonexisting/file').must_equal 'development'
      end
    end
  end

  describe "get_environment" do
    it "returns the environment's name after set up" do
      DotEnv.get_environment('spec/fixtures/dotenv/testenv').must_equal 'staging'
    end
  end
end
