require_relative '../test_helper'
require_relative '../../lib/dot_env/parser'

describe DotEnv::Parser do
  let(:parser) { DotEnv::Parser }

  before do
    ENV['THE_MEANING_OF_LIFE'] = '42'
  end

  it "gets key-value pairs from lines" do
    line = " something = '  some other thing '"

    parser.get_value_pair(line).must_equal ["something", "some other thing"]
  end

  it "expands environment variables" do
    parser.expand("$THE_MEANING_OF_LIFE").must_equal '42'
  end

  it "cleans up variables" do
    value = '["spec", "rspec", "test", "cucumber", $HOME]'
    result = ["spec", "rspec", "test", "cucumber", "$HOME"]

    parser.cleanup(value).must_equal result
  end

  describe "parse" do
    it "handles arrays" do
      value = '["spec", "rspec", "test", "cucumber", $HOME, FALSE]'
      result = ["spec", "rspec", "test", "cucumber", ENV['HOME'], false]

      parser.parse(value).must_equal result
    end

    it "handles booleans" do
      parser.parse("True").must_equal true
    end

    it "handles expandable variables" do
      parser.parse("$HOME").must_equal ENV['HOME']
    end
  end
end
